@@ -11,12 +11,12 @@ module Annex.Ssh (
 ) where
 
 import qualified Data.Map as M
-import System.IO.Error (try)
 
 import Common.Annex
 import Annex.LockPool
 import qualified Git
 import qualified Git.Config
+import qualified Build.SysConfig as SysConfig
 
 {- Generates parameters to ssh to a given host (or user@host) on a given
  - port, with connection caching. -}
@@ -33,17 +33,18 @@ sshParams (host, port) opts = go =<< sshInfo (host, port)
 		-- If the lock pool is empty, this is the first ssh of this
 		-- run. There could be stale ssh connections hanging around
 		-- from a previous git-annex run that was interrupted.
-		cleanstale = whenM (null . filter isLock . M.keys <$> getPool) $
+		cleanstale = whenM (not . any isLock . M.keys <$> getPool) $
 			sshCleanup
 
 sshInfo :: (String, Maybe Integer) -> Annex (Maybe FilePath, [CommandParam])
 sshInfo (host, port) = do
-	caching <- Git.configTrue <$> fromRepo (Git.Config.get "annex.sshcaching" "true")
+	caching <- fromMaybe SysConfig.sshconnectioncaching . Git.configTrue
+		<$> fromRepo (Git.Config.get "annex.sshcaching" "")
 	if caching
 		then do
-			dir <- fromRepo $ gitAnnexSshDir
+			dir <- fromRepo gitAnnexSshDir
 			let socketfile = dir </> hostport2socket host port
-		 	return $ (Just socketfile, cacheParams socketfile)
+		 	return (Just socketfile, cacheParams socketfile)
 		else return (Nothing, [])
 
 cacheParams :: FilePath -> [CommandParam]
@@ -59,9 +60,9 @@ portParams (Just port) = [Param "-p", Param $ show port]
 {- Stop any unused ssh processes. -}
 sshCleanup :: Annex ()
 sshCleanup = do
-	dir <- fromRepo $ gitAnnexSshDir
-	liftIO $ createDirectoryIfMissing True dir
-	sockets <- filter (not . isLock) <$> liftIO (dirContents dir)
+	dir <- fromRepo gitAnnexSshDir
+	sockets <- filter (not . isLock) <$>
+		liftIO (catchDefaultIO (dirContents dir) [])
 	forM_ sockets cleanup
 	where
 		cleanup socketfile = do
@@ -72,18 +73,20 @@ sshCleanup = do
 			let lockfile = socket2lock socketfile
 			unlockFile lockfile
 			fd <- liftIO $ openFd lockfile ReadWrite (Just stdFileMode) defaultFileFlags
-			v <- liftIO $ try $ setLock fd (WriteLock, AbsoluteSeek, 0, 0)
+			v <- liftIO $ tryIO $
+				setLock fd (WriteLock, AbsoluteSeek, 0, 0)
 			case v of
 				Left _ -> return ()
 				Right _ -> stopssh socketfile
 			liftIO $ closeFd fd
 		stopssh socketfile = do
-			(_, params) <- sshInfo $ socket2hostport socketfile
+			let (host, port) = socket2hostport socketfile
+			(_, params) <- sshInfo (host, port)
 			_ <- liftIO $ do
 				-- "ssh -O stop" is noisy on stderr even with -q
 				let cmd = unwords $ toCommand $
 					[ Params "-O stop"
-					] ++ params
+					] ++ params ++ [Param host]
 				_ <- boolSystem "sh"
 					[ Param "-c"
 					, Param $ "ssh " ++ cmd ++ " >/dev/null 2>/dev/null"
@@ -101,7 +104,7 @@ hostport2socket host (Just port) = host ++ "!" ++ show port
 socket2hostport :: FilePath -> (String, Maybe Integer)
 socket2hostport socket
 	| null p = (h, Nothing)
-	| otherwise = (h, readMaybe p)
+	| otherwise = (h, readish p)
 	where
 		(h, p) = separate (== '!') $ takeFileName socket
 
