@@ -33,7 +33,7 @@ seek :: CommandSeek
 seek rs = do
 	!branch <- fromMaybe nobranch <$> inRepo Git.Branch.current
 	remotes <- syncRemotes rs
-	return $ concat $
+	return $ concat
 		[ [ commit ]
 		, [ mergeLocal branch ]
 		, [ pullRemote remote branch | remote <- remotes ]
@@ -75,6 +75,7 @@ commit = do
 	showStart "commit" ""
 	next $ next $ do
 		showOutput
+		Annex.Branch.commit "update"
 		-- Commit will fail when the tree is clean, so ignore failure.
 		_ <- inRepo $ Git.Command.runBool "commit"
 			[Param "-a", Param "-m", Param "git-annex automatic sync"]
@@ -137,9 +138,9 @@ pushRemote remote branch = go =<< needpush
 			showStart "push" (Remote.name remote)
 			next $ next $ do
 				showOutput
-				inRepo $ Git.Command.runBool "push" $
+				inRepo $ Git.Command.runBool "push"
 					[ Param (Remote.name remote)
-					, Param (show $ Annex.Branch.name)
+					, Param (show Annex.Branch.name)
 					, Param refspec
 					]
 		refspec = show (Git.Ref.base branch) ++ ":" ++ show (Git.Ref.base syncbranch)
