@@ -10,7 +10,8 @@
 module Command.Unused where
 
 import qualified Data.Set as S
-import qualified Data.ByteString.Lazy.Char8 as L
+import qualified Data.Text.Lazy as L
+import qualified Data.Text.Lazy.Encoding as L
 
 import Common.Annex
 import Command
@@ -38,7 +39,7 @@ fromOption :: Option
 fromOption = Option.field ['f'] "from" paramRemote "remote to check for unused content"
 
 seek :: [CommandSeek]
-seek = [withNothing $ start]
+seek = [withNothing start]
 
 {- Finds unused content in the annex. -} 
 start :: CommandStart
@@ -47,6 +48,7 @@ start = do
 	let (name, action) = case from of
 		Nothing -> (".", checkUnused)
 		Just "." -> (".", checkUnused)
+		Just "here" -> (".", checkUnused)
 		Just n -> (n, checkRemoteUnused n)
 	showStart "unused" name
 	next action
@@ -161,7 +163,7 @@ excludeReferenced l = do
 		refs = map (Git.Ref .  snd) .
 			nubBy uniqref .
 			filter ourbranches .
-			map (separate (== ' ')) . lines . L.unpack
+			map (separate (== ' ')) . lines
 		uniqref (a, _) (b, _) = a == b
 		ourbranchend = '/' : show Annex.Branch.name
 		ourbranches (_, b) = not $ ourbranchend `isSuffixOf` b
@@ -202,7 +204,7 @@ getKeysReferencedInGit ref = do
 		findkeys c [] = return c
 		findkeys c (l:ls)
 			| isSymLink (LsTree.mode l) = do
-				content <- catFile ref $ LsTree.file l
+				content <- L.decodeUtf8 <$> catFile ref (LsTree.file l)
 				case fileKey (takeFileName $ L.unpack content) of
 					Nothing -> findkeys c ls
 					Just k -> findkeys (k:c) ls
