@@ -68,7 +68,7 @@ gitPreCommitHookUnWrite = unlessBare $ do
 				" Edit it to remove call to git annex."
 
 unlessBare :: Annex () -> Annex ()
-unlessBare = unlessM $ fromRepo $ Git.repoIsLocalBare
+unlessBare = unlessM $ fromRepo Git.repoIsLocalBare
 
 preCommitHook :: Annex FilePath
 preCommitHook = (</>) <$> fromRepo Git.gitDir <*> pure "hooks/pre-commit"
