@@ -52,6 +52,7 @@ gen r u c = do
 			removeKey = remove o,
 			hasKey = checkPresent r o,
 			hasKeyCheap = False,
+			whereisKey = Nothing,
 			config = Nothing,
 			repo = r,
 			remotetype = remote
@@ -118,8 +119,8 @@ retrieveCheap o k f = do
 		then retrieve o k f
 		else return False
 
-retrieveEncrypted :: RsyncOpts -> (Cipher, Key) -> FilePath -> Annex Bool
-retrieveEncrypted o (cipher, enck) f = withTmp enck $ \tmp -> do
+retrieveEncrypted :: RsyncOpts -> (Cipher, Key) -> Key -> FilePath -> Annex Bool
+retrieveEncrypted o (cipher, enck) _ f = withTmp enck $ \tmp -> do
 	res <- retrieve o enck tmp
 	if res
 		then liftIO $ catchBoolIO $ do
@@ -181,8 +182,8 @@ withRsyncScratchDir a = do
 	liftIO $ createDirectoryIfMissing True tmp
 	nuke tmp `after` a tmp
 	where
-		nuke d = liftIO $ 
-			doesDirectoryExist d >>? removeDirectoryRecursive d
+		nuke d = liftIO $ whenM (doesDirectoryExist d) $
+			removeDirectoryRecursive d
 
 rsyncRemote :: RsyncOpts -> [CommandParam] -> Annex Bool
 rsyncRemote o params = do
